==> xmlworker-1.0.0-sources.jar: com/itextpdf/tool/xml/parser/state/TagAttributeState.java <==
/*
 * $Id: TagAttributeState.java 105 2011-05-26 10:18:21Z redlab_b $
 *
 * This file is part of the iText (R) project.
 * Copyright (c) 1998-2011 1T3XT BVBA
 * Authors: Balder Van Camp, Emiel Ackermann, et al.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation with the addition of the
 * following permission added to Section 15 as permitted in Section 7(a):
 * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
 * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 * You should have received a copy of the GNU Affero General Public License
 * along with this program; if not, see http://www.gnu.org/licenses or write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA, 02110-1301 USA, or download the license from the following URL:
 * http://itextpdf.com/terms-of-use/
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License,
 * a covered work must retain the producer line in every PDF that is created
 * or manipulated using iText.
 *
 * You can be released from the requirements of the license by purchasing
 * a commercial license. Buying such a license is mandatory as soon as you
 * develop commercial activities involving the iText software without
 * disclosing the source code of your own applications.
 * These activities include: offering paid services to customers as an ASP,
 * serving PDFs on the fly in a web application, shipping iText with a closed
 * source product.
 *
 * For more information, please contact iText Software Corp. at this
 * address: sales@itextpdf.com
 */
package com.itextpdf.tool.xml.parser.state;

import com.itextpdf.tool.xml.parser.State;
import com.itextpdf.tool.xml.parser.XMLParser;

/**
 * @author redlab_b
 *
 */
public class TagAttributeState implements State {

	private final XMLParser parser;

	/**
	 * @param parser the XMLParser
	 */
	public TagAttributeState(final XMLParser parser) {
		this.parser = parser;
	}

	/* (non-Javadoc)
	 * @see com.itextpdf.tool.xml.parser.State#process(int)
	 */
	public void process(final int character) {
		if (character == '/') {
			// self closing tag detected
			parser.selectState().selfClosing();
		} else if (character == '=') {
			this.parser.memory().currentAttr(this.parser.bufferToString());
			this.parser.flush();
			this.parser.selectState().attributeValue();
		} else if (Character.isWhitespace(character)){
			String attr = this.parser.bufferToString();
			if (attr.length() > 0) {
				this.parser.memory().currentAttr(attr);
				this.parser.flush();
			}
		} else if (character == '>') {
			this.parser.startElement();
			this.parser.flush();
			this.parser.selectState().inTag();
		} else if (character == '?'){
			this.parser.startElement();
			this.parser.flush();
			this.parser.selectState().xml();
		} else {
			this.parser.append(character);
		}

	}

}

==> xmlworker-1.1.0-sources.jar: com/itextpdf/tool/xml/parser/state/TagAttributeState.java <==
/*
 * $Id: TagAttributeState.java 214 2011-08-09 21:31:36Z redlab_b $
 *
 * This file is part of the iText (R) project.
 * Copyright (c) 1998-2011 1T3XT BVBA
 * Authors: Balder Van Camp, Emiel Ackermann, et al.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation with the addition of the
 * following permission added to Section 15 as permitted in Section 7(a):
 * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
 * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 * You should have received a copy of the GNU Affero General Public License
 * along with this program; if not, see http://www.gnu.org/licenses or write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA, 02110-1301 USA, or download the license from the following URL:
 * http://itextpdf.com/terms-of-use/
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License,
 * a covered work must retain the producer line in every PDF that is created
 * or manipulated using iText.
 *
 * You can be released from the requirements of the license by purchasing
 * a commercial license. Buying such a license is mandatory as soon as you
 * develop commercial activities involving the iText software without
 * disclosing the source code of your own applications.
 * These activities include: offering paid services to customers as an ASP,
 * serving PDFs on the fly in a web application, shipping iText with a closed
 * source product.
 *
 * For more information, please contact iText Software Corp. at this
 * address: sales@itextpdf.com
 */
package com.itextpdf.tool.xml.parser.state;

import com.itextpdf.tool.xml.parser.State;
import com.itextpdf.tool.xml.parser.XMLParser;

/**
 * @author redlab_b
 *
 */
public class TagAttributeState implements State {

	private final XMLParser parser;

	/**
	 * @param parser the XMLParser
	 */
	public TagAttributeState(final XMLParser parser) {
		this.parser = parser;
	}

	/* (non-Javadoc)
	 * @see com.itextpdf.tool.xml.parser.State#process(int)
	 */
	public void process(final char character) {
		if (character == '/') {
			// self closing tag detected
			parser.selectState().selfClosing();
		} else if (character == '=') {
			this.parser.memory().currentAttr(this.parser.bufferToString());
			this.parser.flush();
			this.parser.selectState().attributeValue();
		} else if (Character.isWhitespace(character)){
			setAttribute();
		} else if (character == '>') {
			checkAttributeWithNoValue();
			this.parser.startElement();
			this.parser.flush();
			this.parser.selectState().inTag();
		} else if (character == '?'){
			checkAttributeWithNoValue();
			this.parser.startElement();
			this.parser.flush();
			this.parser.selectState().xml();
		} else if (this.parser.memory().hasCurrentAttribute() && !Character.isWhitespace(character)) {
			// assume attribute with no value, example tag <?formServer defaultPDFRenderFormat acrobat8.1dynamic?>
			this.parser.memory().putCurrentAttrValue("");
			this.parser.append(character);
		} else {
			this.parser.append(character);
		}

	}

	private void checkAttributeWithNoValue() {
		if (setAttribute()) {
			this.parser.memory().putCurrentAttrValue("");
		}
	}

	/**
	 * @return true if an attribute was set
	 *
	 */
	protected boolean setAttribute() {
		String attr = this.parser.bufferToString();
		if (attr.length() > 0) {
			this.parser.memory().currentAttr(attr);
			this.parser.flush();
			return true;
		}
		return false;
	}

}
